@@ -326,12 +326,12 @@ bool Catalog::cachePageTree(int page)
   return false;
 }
 
-int Catalog::findPage(int num, int gen) {
+int Catalog::findPage(const Ref pageRef) {
   int i;
 
   for (i = 0; i < getNumPages(); ++i) {
     Ref *ref = getPageRef(i+1);
-    if (ref != nullptr && ref->num == num && ref->gen == gen)
+    if (ref != nullptr && *ref == pageRef)
       return i + 1;
   }
   return 0;
@@ -502,7 +502,7 @@ void Catalog::addEmbeddedFile(GooFile *file, const std::string &fileName)
   embeddedFilesObj.dictSet("Names", Object(embeddedFilesNamesArray));
   namesDict->set("EmbeddedFiles", Object(embeddedFilesRef));
 
-  if (namesObjRef.num != 0) {
+  if (namesObjRef != Ref::INVALID()) {
     xref->setModifiedObject(&namesObj, namesObjRef);
   } else {
     xref->setModifiedObject(&catDict, { xref->getRootNum(), xref->getRootGen() });
