@@ -6,6 +6,7 @@
  * Copyright (C) 2008, 2009, Pino Toscano <pino@kde.org>
  * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
  * Copyright (C) 2019, Oliver Sander <oliver.sander@tu-dresden.de>
+ * Copyright (C) 2019, Jan Grulich <jgrulich@redhat.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,6 +53,11 @@ QString FontInfo::name() const
 	return m_data->fontName;
 }
 
+QString FontInfo::substituteName() const
+{
+	return m_data->fontSubstituteName;
+}
+
 QString FontInfo::file() const
 {
 	return m_data->fontFile;
